# Application Checker
# Simple Journal Module (SimpleJournal.pm)
#
# Copyright (C) 2007-2010 The Linux Foundation. All rights reserved.
#
# This program has been developed by ISP RAS for LF.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

package SimpleJournal;
use strict;

# Class constructor
# Creates and opens the journal file specified as an input parameter
sub new($$) {
	my ($class, $filename) = @_;
	my $self  = {};

	if (defined($filename)) {
		$self->{'FILENAME'} = $filename;

		my $fh;
		if (open($fh, ">$filename")) {
			$self->{'FILEHANDLE'} = $fh;
		}
		else {
			$self->{'ERROR'} = "Failed to open journal '$filename' for writing: $!";
		}
	}
	else {
		$self->{'ERROR'} = 'Filename undefined!';
	}

	bless($self);
	return $self;
}

# Closes the journal file
sub close($) {
	my ($self) = @_;
	delete $self->{'ERROR'};

	$self->write_line('FINISHED');

	if (close($self->{'FILEHANDLE'})) {
		$self->{'FILEHANDLE'} = undef;
		return 1;
	}
	else {
		$self->{'ERROR'} = "Failed to close the filehandle: $!";
		return 0;
	}
}

# Auxiliary funciton for writing data into the journal file
sub write_line($$) {
	my ($self, $text) = @_;
	delete $self->{'ERROR'};

	print {$self->{FILEHANDLE}} $text."\n";
}

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Functions for filling in the journal with data

sub test_name($$) {
	my ($self, $test_name) = @_;
	delete $self->{'ERROR'};

	$self->write_line("TEST: $test_name");
}

sub tests_expected($$) {
	my ($self, $expected_num) = @_;
	delete $self->{'ERROR'};

	$self->write_line("TESTS_EXPECTED: $expected_num");
}

sub test_case_start($$) {
	my ($self, $tc_name) = @_;
	delete $self->{'ERROR'};

	$self->write_line("TESTCASE: $tc_name");
}

sub test_description($$) {
	my ($self, $text) = @_;
	delete $self->{'ERROR'};

	foreach (split(/\n/, $text)) {
		$self->write_line(" DESCR: $_");
	}
}

sub test_comment($$) {
	my ($self, $text) = @_;
	delete $self->{'ERROR'};

	foreach (split(/\n/, $text)) {
		$self->write_line(" COMMENT: $_");
	}
}

sub test_message($$) {
	my ($self, $text) = @_;
	delete $self->{'ERROR'};

	foreach (split(/\n/, $text)) {
		$self->write_line(" MESSAGE: $_");
	}
}

sub test_case_result($$) {
	my ($self, $res) = @_;
	delete $self->{'ERROR'};

	$self->write_line("RESULT: $res");
}


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Simple journal parser

package SimpleJournalParser;
use strict;

# Class constructor
# Opens the journal file specified as an input parameter
sub new($$) {
	my ($class, $filename) = @_;
	my $self  = {};

	if (defined($filename)) {
		$self->{'FILENAME'} = $filename;

		if (open(TEST_JOURNAL, $filename)) {
			my $testcase_id;
			while(<TEST_JOURNAL>) {
				if (m/^TESTCASE:\s*(\S.*)$/i) {
					$testcase_id = $1;
				}
				elsif (m/^RESULT:\s*(passed|failed)$/i) {
					$self->{'TESTCASES'}->{$testcase_id} = (($1 eq 'passed') ? 'yes' : 'no') if ($testcase_id);
				}
			}
			close(TEST_JOURNAL);
		}
		else {
			$self->{'ERROR'} = "Failed to open journal '$filename' for reading: $!";
		}
	}
	else {
		$self->{'ERROR'} = 'Filename undefined!';
	}

	bless($self);
	return $self;
}

1; # return value
